@@ -11,22 +11,18 @@ there is no code to install a boot loader on the recovered system
 or the code that we have failed to install the boot loader correctly.
 Please contribute appropriate code to the $PRODUCT project,
 see http://relax-and-recover.org/development/
-Take a look at the scripts in $SHARE_DIR/finalize,
-for example see the scripts
-$SHARE_DIR/finalize/Linux-i386/630_install_grub.sh
+Take a look at the scripts in $SHARE_DIR/finalize - for example
+for PC architectures like x86 and x86_64 see the script
 $SHARE_DIR/finalize/Linux-i386/660_install_grub2.sh
-
+and for POWER architectures like ppc64le see the script
+$SHARE_DIR/finalize/Linux-ppc64le/660_install_grub2.sh
 ---------------------------------------------------
 |  IF YOU DO NOT INSTALL A BOOT LOADER MANUALLY,  |
 |  THEN YOUR SYSTEM WILL NOT BE ABLE TO BOOT.     |
 ---------------------------------------------------
-
 You can use 'chroot $TARGET_FS_ROOT bash --login'
-to change into the recovered system.
-You should at least mount /proc in the recovered system
-e.g. via 'mount -t proc none $TARGET_FS_ROOT/proc'
-before you change into the recovered system
-and manually install a boot loader therein.
+to change into the recovered system and
+manually install a boot loader therein.
 "
 
 fi
