@@ -6,9 +6,9 @@ fi
 config_files=()
 for obj in "${CHECK_CONFIG_FILES[@]}" ; do
     if [ -d "$obj" ] ; then
-        config_files=( "${config_files[@]}" $(find "$obj" -type f) )
+        config_files+=( $( find "$obj" -type f ) )
     elif [ -e "$obj" ] ; then
-        config_files=( "${config_files[@]}" "$obj")
+        config_files+=( "$obj")
     fi
 done
 md5sum "${config_files[@]}" > $VAR_DIR/layout/config/files.md5sum
