@@ -128,8 +128,13 @@ function log_descendants_pids () {
 function terminate_descendants_from_grandchildren_to_children () {
     # Some descendant processes commands could be much too long (e.g. a 'tar ...' command)
     # to be usefully shown completely in the below LogPrint information (could be many lines)
-    # so that the descendant process command output is truncated after at most remaining_columns:
-    local remaining_columns=$(( COLUMNS - 40 ))
+    # so that the descendant process command output is truncated after at most remaining_columns.
+    # We reserve 40 characters for the log prefix and show at most 40 characters of the command.
+    # The shell variable COLUMNS is not defined in noninteractive bash, so we set a fallback
+    # cf. https://github.com/rear/rear/pull/1720#discussion_r328686592
+    local remaining_columns
+    test $COLUMNS && remaining_columns=$COLUMNS || remaining_columns=80
+    remaining_columns=$(( remaining_columns - 40 ))
     test $remaining_columns -ge 40 || remaining_columns=40
     # Terminate all still running descendant processes of MASTER_PID
     # but do not terminate the MASTER_PID process itself because
@@ -185,7 +190,9 @@ function terminate_descendants_from_grandchildren_to_children () {
 # except small but crucial differences here which is the reason why that kind of code exists two times.
 function terminate_descendants_from_children_to_grandchildren () {
     # Some descendant processes commands could be much too long (e.g. a 'tar ...' command):
-    local remaining_columns=$(( COLUMNS - 40 ))
+    local remaining_columns
+    test $COLUMNS && remaining_columns=$COLUMNS || remaining_columns=80
+    remaining_columns=$(( remaining_columns - 40 ))
     test $remaining_columns -ge 40 || remaining_columns=40
     # Terminate all still running descendant processes of MASTER_PID
     # but do not terminate the MASTER_PID process itself because
@@ -365,7 +372,7 @@ function trap () {
 # but only when the user launched 'rear -v' in verbose mode:
 function Print () {
     # It is crucial to append to /dev/$DISPENSABLE_OUTPUT_DEV when $DISPENSABLE_OUTPUT_DEV is not 'null'.
-    # In debugscripts mode $DISPENSABLE_OUTPUT_DEV is 'stderr' (see usr/sbin/rear)
+    # In debugscript mode $DISPENSABLE_OUTPUT_DEV is 'stderr' (see usr/sbin/rear)
     # and /dev/stderr is fd2 which is redirected to append to RUNTIME_LOGFILE (see usr/sbin/rear)
     # so that 2>/dev/stderr would truncate RUNTIME_LOGFILE to zero size (see 'REDIRECTION' in "man bash")
     # but 2>>/dev/stderr does not change things so that fd2 output is still appended to RUNTIME_LOGFILE:
@@ -401,7 +408,12 @@ function Log () {
           log_message="${MESSAGE_PREFIX}${timestamp}$( cat )"
       fi
     } 2>>/dev/$DISPENSABLE_OUTPUT_DEV
-    echo "$log_message" 1>&2 || true
+    # Append the log message explicitly to the log file to ensure that intended log messages
+    # actually appear in the log file even inside { ... } 2>>/dev/$DISPENSABLE_OUTPUT_DEV
+    # e.g. as in { COMMAND || Log "COMMAND failed" ; } 2>>/dev/$DISPENSABLE_OUTPUT_DEV
+    # cf. the 2>>/dev/$DISPENSABLE_OUTPUT_DEV usage in the RequiredSharedObjects function
+    # and in build/GNU/Linux/100_copy_as_is.sh and build/GNU/Linux/390_copy_binaries_libraries.sh
+    echo "$log_message" >>"$RUNTIME_LOGFILE" || true
 }
 
 # For messages that should only appear in the log file when the user launched 'rear -d' in debug mode:
@@ -430,8 +442,15 @@ function LogUserOutput () {
     UserOutput "$@"
 }
 
-# For messages that should appear in the log file and also
-# on the user's terminal regardless whether or not the user launched 'rear' in verbose mode:
+# For important messages that should appear in the log file and also
+# on the user's terminal regardless whether or not the user launched 'rear' in verbose mode.
+# LogPrintError does not error out (the Error function is meant to error out).
+# LogPrintError is meant to show error messages when we do not want to error out,
+# (for example when at the end of "rear recover" it failed to install a bootloader).
+# LogPrintError is also meant to show important "error-like" messages to the user
+# (for example when the user must decide if that means a real error in his case)
+# and other important messages that must appear on the user's terminal
+# cf. https://blog.schlomo.schapiro.org/2015/04/warning-is-waste-of-my-time.html
 function LogPrintError () {
     Log "$@"
     PrintError "$@"
@@ -545,7 +564,7 @@ function Error () {
     # (but do not stop at lines that are logged like '++ StopIfError ...' or '++ PrintError ...')
     # if such a '+ Error' or '+ BugError' line exists, otherwise sed proceeds to the end
     # (the sed pattern '[Bug]*Error' is fuzzy because it would also match things like 'uuggError').
-    # The reason to stop at a line that contains '+ [Bug]*Error ' is that in debugscripts mode '-D'
+    # The reason to stop at a line that contains '+ [Bug]*Error ' is that in debugscript mode '-D'
     # a BugError or Error function call with a multi line error message (e.g. BugError does that)
     # results 'set -x' debug output of that function call in the log file that looks like:
     #   ++ [Bug]Error 'first error message line
@@ -756,11 +775,16 @@ function LogPrintIfError () {
 #       the prompt, the actual input, the default value, and the choices are still shown on the user's terminal.
 #       In confidential user input mode the actual input coming from the user's terminal is still echoed
 #       on the user's terminal unless also the -s option is specified.
-#       When usr/sbin/rear is run in debugscripts mode (which runs the scripts with 'set -x') arbitrary values
-#       appear in the log file so that the confidential user input mode does not help in debugscripts mode.
-#       If confidential user input is needed also in debugscripts mode the caller of the UserInput function
-#       must call it in an appropriate (temporary) environment e.g. with STDERR redirected to /dev/null like:
+#       When usr/sbin/rear is run in debugscript mode (which runs the scripts with 'set -x') arbitrary values
+#       appear in the log file so that the confidential user input mode does not help in debugscript mode.
+#       If confidential user input is needed also in debugscript mode the caller of the UserInput function
+#       must call it in an appropriate (temporary) environment e.g. with STDERR redirected to /dev/null like
 #           { password="$( UserInput -I PASSWORD -C -r -s -p 'Enter the pasword' )" ; } 2>/dev/null
+#       The redirection must be done via a compound group command { confidential_command ; } 2>/dev/null
+#       even for a single confidential command to ensure STDERR is redirected to /dev/null also for 'set -x'
+#       otherwise the confidential command and its arguments would be shown in the log file, for example
+#           { openssl des3 -salt -k secret_passphrase ; } 2>/dev/null
+#       where the secret passphrase must not appear in the log, cf. https://github.com/rear/rear/issues/2155
 # Result:
 #   Any actual user input or an automated user input or the default response is output via STDOUT.
 # Return code:
