@@ -42,7 +42,7 @@ function Source () {
     Log "Including $relname"
     # DEBUGSCRIPTS mode settings:
     if test "$DEBUGSCRIPTS" ; then
-        Debug "Entering debugscripts mode via 'set -$DEBUGSCRIPTS_ARGUMENT'."
+        Debug "Entering debugscript mode via 'set -$DEBUGSCRIPTS_ARGUMENT'."
         local saved_bash_flags_and_options_commands="$( get_bash_flags_and_options_commands )"
         set -$DEBUGSCRIPTS_ARGUMENT
     fi
@@ -58,7 +58,7 @@ function Source () {
     test "0" -eq "$source_return_code" || Debug "Source function: 'source $source_file' returns $source_return_code"
     # Undo DEBUGSCRIPTS mode settings:
     if test "$DEBUGSCRIPTS" ; then
-        Debug "Leaving debugscripts mode (back to previous bash flags and options settings)."
+        Debug "Leaving debugscript mode (back to previous bash flags and options settings)."
         # The only known way how to do 'set +x' after 'set -x' without 'set -x' output for the 'set +x' call
         # is a current shell environment where stderr is redirected to /dev/null before 'set +x' is run via
         #   { set +x ; } 2>/dev/null
@@ -121,7 +121,7 @@ function SourceStage () {
 function cleanup_build_area_and_end_program () {
     # Cleanup build area
     Log "Finished in $((SECONDS-STARTTIME)) seconds"
-    if test "$KEEP_BUILD_DIR" ; then
+    if is_true "$KEEP_BUILD_DIR" ; then
         LogPrint "You should also rm -Rf $BUILD_DIR"
     else
         Log "Removing build area $BUILD_DIR"
@@ -130,8 +130,7 @@ function cleanup_build_area_and_end_program () {
         # line below put in comment due to issue #465
         #rm -Rf $BUILD_DIR/outputfs
         # in worst case it could not umount; so before remove the BUILD_DIR check if above outputfs is gone
-        mount | grep -q "$BUILD_DIR/outputfs"
-        if [[ $? -eq 0 ]]; then
+        if mountpoint -q "$BUILD_DIR/outputfs" ; then
             # still mounted it seems
             LogPrint "Directory $BUILD_DIR/outputfs still mounted - trying lazy umount"
             sleep 2
