@@ -21,7 +21,7 @@ save_original_file() {
     local extension="$2"
     test "$extension" || extension=$WORKFLOW.$MASTER_PID
     local saved_original_file="$filename.$DATE.$extension.$SAVED_ORIGINAL_FILE_SUFFIX"
-    cp -ar $filename $saved_original_file && SAVED_ORIGINAL_FILES=( "${SAVED_ORIGINAL_FILES[@]}" "$filename" )
+    cp -ar $filename $saved_original_file && SAVED_ORIGINAL_FILES+=( "$filename" )
 }
 
 # Restore the saved original content of the original file named $1
@@ -35,7 +35,7 @@ restore_original_file() {
     cp -ar $saved_original_file $filename
 }
 
-# Generate code to restore a device $1 of type $2.
+# Generate code to recreate a device $1 of type $2 and then mount it.
 # Note that we do not handle partitioning here.
 create_device() {
     local device="$1"
@@ -58,6 +58,35 @@ fi
 EOF
 }
 
+# Generate code to mount a device $1 of type $2 ('mountonly' workflow).
+do_mount_device() {
+    local device="$1"
+    local type="$2"
+    local name # used to extract the actual name of the device
+
+    cat <<EOF >> "$LAYOUT_CODE"
+if create_component "$device" "$type" ; then
+EOF
+    # This can be used a.o. to decrypt a LUKS device
+    echo "# Open $device ($type)" >> "$LAYOUT_CODE"
+    if type -t open_$type >/dev/null ; then
+        open_$type "$device"
+    fi
+
+    # If the device is mountable, it will then be mounted
+    echo "# Mount $device ($type)" >> "$LAYOUT_CODE"
+    if type -t mount_$type >/dev/null ; then
+        mount_$type "$device"
+    fi
+    cat <<EOF >> "$LAYOUT_CODE"
+component_created "$device" "$type"
+else
+    LogPrint "Skipping $device ($type) as it has already been mounted."
+fi
+
+EOF
+}
+
 abort_recreate() {
     Log "Error detected during restore."
     Log "Restoring saved original $LAYOUT_FILE"
@@ -187,7 +216,7 @@ generate_layout_dependencies() {
                 ;;
             multipath)
                 name=$(echo "$remainder" | cut -d " " -f "1")
-                disks=$(echo "$remainder" | cut -d " " -f "3" | tr "," " ")
+                disks=$(echo "$remainder" | cut -d " " -f "4" | tr "," " ")
 
                 add_component "$name" "multipath"
 
@@ -248,12 +277,14 @@ get_child_components() {
                 if IsInArray "$child" "${children[@]}" ; then
                     continue
                 fi
-                devlist=( "${devlist[@]}" "$child" )
-                children=( "${children[@]}" "$child" )
+                devlist+=( "$child" )
+                children+=( "$child" )
             fi
         done < $LAYOUT_DEPS
 
-        ### remove the current element from the array and re-index it
+        # remove the current element from the array and re-index it because
+        # "unset does not remove the element it just sets null string to the particular index in array"
+        # see https://stackoverflow.com/questions/16860877/remove-an-element-from-a-bash-array
         unset "devlist[0]"
         devlist=( "${devlist[@]}" )
     done
@@ -288,12 +319,14 @@ get_parent_components() {
                     continue
                 fi
                 ### ...and add them to the list
-                devlist=( "${devlist[@]}" "$parent" )
-                ancestors=( "${ancestors[@]}" "$parent" )
+                devlist+=( "$parent" )
+                ancestors+=( "$parent" )
             fi
         done < $LAYOUT_DEPS
 
-        ### remove the current element from the array and re-index it
+        # remove the current element from the array and re-index it because
+        # "unset does not remove the element it just sets null string to the particular index in array"
+        # see https://stackoverflow.com/questions/16860877/remove-an-element-from-a-bash-array
         unset "devlist[0]"
         devlist=( "${devlist[@]}" )
     done
@@ -317,47 +350,69 @@ find_disk() {
     get_parent_components "$1" "disk"
 }
 
-find_disk_and_multipath() {
-    res=$(find_disk "$1")
-    if [[ -n "$res" || "$AUTOEXCLUDE_MULTIPATH" =~ ^[yY1] ]]; then
-        echo $res
-    else
-        find_multipath "$1"
-    fi
-}
-
 find_multipath() {
     get_parent_components "$1" "multipath"
 }
 
+find_disk_and_multipath() {
+    find_disk "$1"
+    is_true "$AUTOEXCLUDE_MULTIPATH" || find_multipath "$1"
+}
+
 find_partition() {
     get_parent_components "$1" "part"
 }
 
-# Function returns partition number of partition block device name
-#
+# The get_partition_number function
+# outputs the trailing digits of a partition block device as its partition number.
+# Usually only the basename of the partition block device is used as function argument
+# e.g. "get_partition_number sda2" instead of "get_partition_number /dev/sda2".
+# The implementation requires grep v2.5 or higher (option -o is used).
 # This function should support:
 #   /dev/mapper/36001438005deb05d0000e00005c40000p1
 #   /dev/mapper/36001438005deb05d0000e00005c40000_part1
 #   /dev/sda1
 #   /dev/cciss/c0d0p1
-#
-# Requires: grep v2.5 or higher (option -o)
-
 get_partition_number() {
-    local partition=$1
-    local number=$(echo "$partition" | grep -o -E "[0-9]+$")
+    local partition_block_device=$1
 
-    # Test if $number is a positive integer, if not it is a bug
-    [ $number -gt 0 ] 2>/dev/null
-    StopIfError "Partition number '$number' of partition $partition is not a valid number."
+    # The partition number is the trailing digits of the partition block device:
+    local partition_number=$( echo "$partition_block_device" | grep -o -E '[0-9]+$' )
 
-    # Catch if $number is too big, report it as a bug
-    (( $number <= 128 ))
-    StopIfError "Partition $partition is numbered '$number'. More than 128 partitions is not supported."
+    # Test if partition_number is a positive integer, if not it is likely a bug in ReaR.
+    # Because the above 'grep' outputs only trailing digits this BugError gets triggred
+    # when partition_block_device device does not contain trailing digits so that partition_number is empty
+    # which can happen when get_partition_number is called with a block device as argument
+    # that is not a partition block device (e.g. /dev/sda instead of /dev/sda1) which is likely a bug in ReaR:
+    test $partition_number -gt 0 || BugError "Partition number '$partition_number' of partition $partition_block_device is not a valid partition number."
 
-    echo $number
+    # Test if partition_number is greater than 128 and report it as a bug in ReaR.
+    # FIXME: Why are more than 128 partitions not supported?
+    # Why is it a bug in ReaR when more than 128 partitions are not supported?
+    # A GPT must be for at least 128 partitions but why does ReaR not support bigger GPT?
+    # I <jsmeix@suse.de> found https://github.com/rear/rear/commit/e758bba0a415173952cc588e5cf80570a6385f7e that links to
+    # https://github.com/rear/rear/issues/263 that contains https://github.com/rear/rear/issues/263#issuecomment-20464763
+    # which reads (excerpt): "The GPT standard allows maximum of 128 partitions per disk" which is not true
+    # according to how I understand the German https://de.wikipedia.org/wiki/GUID_Partition_Table that reads (excerpt)
+    # "Die EFI-Spezifikationen schreiben ein Minimum von 16384 Bytes für die Partitionstabelle vor, so dass es Platz für 128 Einträge gibt."
+    # in English "EFI specification mandate a minimum of 16384 bytes for the partition table so that there is space for 128 entries"
+    # which matches the English https://en.wikipedia.org/wiki/GUID_Partition_Table that reads (excerpt)
+    # "The UEFI specification stipulates that a minimum of 16384 bytes ... are allocated for the Partition Entry Array. Each entry has a size of 128 bytes."
+    # and because 16384 / 128 = 128 it results that 128 partition table entries (each of 128 bytes) are possible as a minimum
+    # which means that the GPT standard requires a minimum of 128 possible partitions per disk.
+    # So the current BugError here might be changed into only a user notification, for example something like
+    #   LogPrintError "Partition $partition_block_device is numbered '$partition_number'. More than 128 partitions may not work (GPT must be extra large)."
+    # But on the other hand ReaR errors out relatively often at that place here in particular
+    # when weird partition related errors before had been ignored and it proceeded until it finally errors out here
+    # cf. "Try hard to care about possible errors" in https://github.com/rear/rear/wiki/Coding-Style
+    # so we keep the BugError for the time being as some kind of generic safeguard to catch bugs in ReaR elsewhere
+    # until we fully understand what is going on in our partitioning related code, cf. https://github.com/rear/rear/pull/2260
+    test $partition_number -le 128 || BugError "Partition $partition_block_device is numbered '$partition_number'. More than 128 partitions are not supported."
+
+    # Output the trailing digits of the partition block device as its partition number:
+    echo $partition_number
 }
+
 # Returns partition start block or 'unknown'
 # sda/sda1 or
 # dm-XX
@@ -642,7 +697,18 @@ is_disk_a_pv() {
 }
 
 function is_multipath_path {
-    [ "$1" ] && type multipath &>/dev/null && multipath -c /dev/$1 &>/dev/null
+    # Return 'false' if there is no device as argument:
+    test "$1" || return 1
+    # Return 'false' if there is no multipath command:
+    type multipath &>/dev/null || return 1
+    # Return 'false' if multipath is not used, see https://github.com/rear/rear/issues/2298
+    # Because "multipath -l" always returns zero exit code we check if it has real output via grep -q '[[:alnum:]]'
+    # so that no "multipath -l" output could clutter the log (the "multipath -l" output is irrelevant here)
+    # in contrast to e.g. test "$( multipath -l )" that would falsely succeed with blank output
+    # and the output would appear in the log in 'set -x' debugscript mode:
+    multipath -l | grep -q '[[:alnum:]]' || return 1
+    # Check if a block device should be a path in a multipath device:
+    multipath -c /dev/$1 &>/dev/null
 }
 
 # retry_command () is binded with REAR_SLEEP_DELAY and REAR_MAX_RETRIES.
@@ -982,7 +1048,10 @@ function apply_layout_mappings() {
     while read original replacement junk ; do
         # Skip lines that have wrong syntax:
         test "$original" -a "$replacement" || continue
-        if grep -q "$replacement" "$file_to_migrate" ; then
+        # Only treat leftover temporary replacement words as an error
+        # if they are in a non-comment line (comments have '#' as first non-space character)
+        # cf. https://github.com/rear/rear/issues/2183
+        if grep -v '^[[:space:]]*#' "$file_to_migrate" | grep -q "$replacement" ; then
             apply_layout_mappings_succeeded="no"
             LogPrintError "Failed to apply layout mappings to $file_to_migrate for $original (probably no mapping for $original in $MAPPING_FILE)"
         fi
@@ -992,4 +1061,251 @@ function apply_layout_mappings() {
     is_true $apply_layout_mappings_succeeded && return 0 || return 1
 }
 
+has_binary parted || Error "Cannot find 'parted' command"
+
+FEATURE_PARTED_RESIZEPART=y
+FEATURE_PARTED_RESIZE=n
+
+if parted --help | awk '$1 == "resizepart" { exit 1 }' ; then
+    # No 'resizepart', check for 'resize'
+    FEATURE_PARTED_RESIZEPART=n
+    if ! parted --help | awk '$1 == "resize" { exit 1 }' ; then
+        FEATURE_PARTED_RESIZE=y
+        if ! parted --help | awk '$1 == "resize" && $3 == "START" { exit 1 }' ; then
+            # 'parted resize NUM START END' tries resizing the file system,
+            # which is known to fail, as shown below (output from parted):
+            #
+            # # parted -s -m /dev/sdc resize 3 1074790400B 2149580799B
+            # WARNING: you are attempting to use parted to operate on (resize) a file system.
+            # parted's file system manipulation code is not as robust as what you'll find in
+            # dedicated, file-system-specific packages like e2fsprogs.  We recommend
+            # you use parted only to manipulate partition tables, whenever possible.
+            # Support for performing most operations on most types of file systems
+            # will be removed in an upcoming release.
+            # No Implementation: Support for opening ext4 file systems is not implemented yet.
+            FEATURE_PARTED_RESIZE=n
+        fi
+    fi
+fi
+
+# Keeps track of the current disk being processed
+# e.g. /dev/sdb
+current_disk=""
+
+# Keeps track of last partition created for the current disk
+# e.g. last_partition_number=1
+last_partition_number=0
+
+# Keeps track of dummy partitions created and to be removed (due to parted limitation) for the current disk
+# Contains a list of partition numbers
+# e.g. dummy_partitions_to_delete=( 1 2 4 5 )
+dummy_partitions_to_delete=()
+
+# Keeps track of partitions to resize to original size for the current disk
+# Contains a list of partition tuples (number, end_in_bytes)
+# e.g. partitions_to_resize=( 3 2096127 6 8388607 )
+partitions_to_resize=()
+
+# Keeps track of the label for the current disk
+# e.g. disk_label="gpt"
+disk_label=""
+
+#
+# create_disk_label(disk, label)
+#
+# Sets up the disk label. Must be called before calling create_disk_partition().
+#
+create_disk_label() {
+    local disk="$1" label="$2"
+
+    if [[ "$current_disk" ]] && [[ "$current_disk" != "$disk" ]] ; then
+        BugError "Current disk has changed from '$current_disk' to '$disk' without calling delete_dummy_partitions_and_resize_real_ones() first."
+    fi
+    current_disk="$disk"
+
+    if [[ "$disk_label" ]] && [[ "$disk_label" != "$label" ]] ; then
+        BugError "Disk '$disk': disk label is being assigned multiple times for the same disk."
+    fi
+    disk_label="$label"
+
+    LogPrint "Disk '$disk': creating '$label' partition table"
+    parted -s $disk mklabel $label
+    my_udevsettle
+}
+
+#
+# create_disk_partition(disk, name, partnumber, partstart, [partend])
+#
+# Creates a partition. When changing disk, user must call delete_dummy_partitions_and_resize_real_ones().
+#
+create_disk_partition() {
+    local disk="$1" name="$2" number=$3 startB=$4 endB=$5
+
+    #
+    # FIXME? This code assumes that "parted" is capable of handling sizes in
+    # Bytes. parted supports partitions in Bytes since ages.
+    #
+
+    if [[ "$current_disk" ]] && [[ "$current_disk" != "$disk" ]] ; then
+        BugError "Current disk has changed from '$current_disk' to '$disk' without calling delete_dummy_partitions_and_resize_real_ones() first."
+    fi
+    current_disk="$disk"
+
+    if [[ ! "$disk_label" ]] ; then
+        BugError "Disk '$disk': disk label is unknown."
+    fi
+
+    # The duplicated quoting "'$name'" is there because
+    # parted's internal parser needs single quotes for values with blanks.
+    # In particular a GPT partition name that can contain spaces
+    # like 'EFI System Partition' cf. https://github.com/rear/rear/issues/1563
+    # so that when calling parted on command line it must be done like
+    #    parted -s /dev/sdb unit MiB mkpart "'partition name'" 12 34
+    # where the outer quoting "..." is for bash so that
+    # the inner quoting '...' is preserved for parted's internal parser:
+    [ "$disk_label" == "msdos" ] || name="'$name'"
+
+    if [[ $number -le last_partition_number ]] ; then
+        Error "Disk '$disk': trying to create partition number $number but last created partition was number $last_partition_number"
+    fi
+
+    if [[ $(( $number - $last_partition_number - 1 )) -eq 0 ]] ; then
+        LogPrint "Disk '$disk': creating partition number $number with name '$name'"
+        # FIXME: I <jsmeix@suse.de> think one cannot silently set the end of a partition to 100%
+        # if there is no partition end value, I think in this case "rear recover" should error out:
+        if [[ ! $endB ]] ; then
+            parted -s $disk mkpart "$name" "${startB}B" 100%
+        else
+            parted -s $disk mkpart "$name" "${startB}B" "${endB}B"
+        fi
+        my_udevsettle
+        last_partition_number=$number
+        return 0
+    fi
+
+    if is_false $FEATURE_PARTED_RESIZEPART && is_false $FEATURE_PARTED_RESIZE ; then
+        Error "Disk '$disk': trying to create partition number $number which isn't consecutive with previous partition but 'parted' doesn't support this feature"
+    fi
+
+    # "parted" is only capable of creating partitions consecutively. Since
+    # there is a gap between the previous partition and this partition, dummy
+    # partitions must be created, and later will be removed once disks are
+    # fully partitioned (this is done in
+    # delete_dummy_partitions_and_resize_real_ones()).
+    #
+    # Once the dummy partitions are removed, the real partition needs to be
+    # resized to original size.
+    # Unfortunately, "parted" is only capable of resizing a partition toward
+    # its end, not the beginning, so the only way to create dummy partitions
+    # appropriately is to use some space at the end of the real partition.
+    #
+    # Example: the GPT disk contains only 1 partition numbered 3 named PART
+    #
+    # # parted -m -s /dev/sda unit B print
+    # /dev/sda:21474836480B:scsi:512:512:gpt:QEMU QEMU HARDDISK:;
+    # 3:1048576B:2097151B:1048576B::PART:;
+    #
+    # We need to create these partitions to recreate the exact same partitions:
+    #
+    # # parted -m -s /dev/sda unit B print
+    # /dev/sda:21474836480B:scsi:512:512:gpt:QEMU QEMU HARDDISK:;
+    # 3:1048576B:2096127B:1047552B::PART:;
+    # 2:2096128B:2096639B:512B::dummy2:;
+    # 1:2096640B:2097151B:512B::dummy1:;
+    #
+    # Then delete dummy partition 1 and 2 and resize 3 to its original end.
+    #
+    # For 'msdos' disks, only non-logical partitions are affected.
+
+    if [[ ! $endB ]] ; then
+        # We need to compute '$endB' based on disk size. To do so, create a
+        # partition then get its end
+        LogPrint "Disk '$disk': creating a temporary partition to find out the end of the disk"
+        parted -s -m $disk mkpart "$name" ${startB}B 100%
+        local num
+        read num endB <<< $( parted -s -m $disk unit B print | tail -1 | awk -F ':' '{ print $1, $3 }' | sed 's/\([0-9]*\)B$/\1/' )
+        LogPrint "Disk '$disk': last allocatable byte on disk is '$endB'"
+        LogPrint "Disk '$disk': deleting the temporary partition number $num"
+        parted -s -m $disk rm $num
+    fi
+
+    partitions_to_resize+=( $number $endB )
+
+    local -i logical_sector_size=$( parted -m -s $disk unit B print | awk -F ':' "\$1 == \"$disk\" { print \$4 }" )
+
+    if [[ "$disk_label" != "msdos" ]] || [[ "$name" != "logical" ]] ; then
+        local -i i=$last_partition_number+1
+        while [[ $i -lt $number ]] ; do
+            local partname="dummy$i"
+            [[ "$disk_label" != "msdos" ]] || partname="primary"
+            dummy_partitions_to_delete+=( $i )
+            LogPrint "Disk '$disk': creating dummy partition number $i with name '$partname' (will be deleted later)"
+            parted -s -m $disk mkpart "$partname" "${endB}B" "${endB}B"
+            my_udevsettle
+            let endB-=$logical_sector_size
+            if [[ $endB -lt $startB ]] ; then
+                # Not enough space left for real partition: this happens if the
+                # partition to create is very small and we cannot create dummy
+                # temporary partitions!
+                # e.g. Partition table starts at partition number 2 and partition 2
+                # has only 1 cylinder
+                Error "Disk '$disk': Cannot create partition number $number, the partition is too small to create dummy partitions to work around parted's limitation (parted can only create consecutive partitions)"
+            fi
+            let i++
+        done
+    fi
+
+    LogPrint "Disk '$disk': creating partition number $number with name '$name'"
+    parted -s $disk mkpart "$name" "${startB}B" "${endB}B"
+    my_udevsettle
+
+    last_partition_number=$number
+}
+
+#
+# delete_dummy_partitions_and_resize_real_ones()
+#
+# When current disk has non-consecutive partitions, delete temporary partitions
+# that have been created and resize the temporary shrinked partitions to their
+# expected size.
+#
+delete_dummy_partitions_and_resize_real_ones() {
+    # If parted doesn't support resizing, this is a no-op function
+    # (dummy_partitions_to_delete will be empty).
+    if [[ ${#dummy_partitions_to_delete[@]} -eq 0 ]] ; then
+        partitions_to_resize=()
+        current_disk=""
+        disk_label=""
+        last_partition_number=0
+        return 0
+    fi
+
+    # Delete dummy partitions
+    local -i num
+    for num in ${dummy_partitions_to_delete[@]} ; do
+        LogPrint "Disk '$current_disk': deleting dummy partition number $num"
+        parted -s -m $current_disk rm $num
+    done
+    dummy_partitions_to_delete=()
+    my_udevsettle
+
+    # Resize previously shrinked partitions (to make place for dummy
+    # partitions) to expected size
+    local -i endB
+    while read num endB ; do
+        LogPrint "Disk '$current_disk': resizing partition number $num to original size"
+        if is_true $FEATURE_PARTED_RESIZEPART ; then
+            parted -s -m $current_disk resizepart $num "${endB}B"
+        else
+            parted -s -m $current_disk resize $num "${endB}B"
+        fi
+    done <<< "$(printf "%d %d\n" "${partitions_to_resize[@]}")"
+    partitions_to_resize=()
+    my_udevsettle
+
+    current_disk=""
+    disk_label=""
+    last_partition_number=0
+}
+
 # vim: set et ts=4 sw=4:
