@@ -2,7 +2,7 @@
 #
 
 WORKFLOW_mkbackup_DESCRIPTION="create rescue media and backup system"
-WORKFLOWS=( ${WORKFLOWS[@]} mkbackup )
+WORKFLOWS+=( mkbackup )
 WORKFLOW_mkbackup () {
 	local scheme=$(url_scheme $BACKUP_URL)
 
